
Installation
============

Pallas requires Python 3.7 or newer. It can be installed using pip:

.. code-block:: shell

    pip install pallas


When Pandas_ are installed, query results can be converted to :class:`pandas.DataFrame`.

.. code-block:: shell

    pip install pallas[pandas]


.. _Pandas: https://pandas.pydata.org
